@@ -1,4 +1,4 @@
-"""
+'''
 # AWS Data Pipeline Construct Library
 
 <!--BEGIN STABILITY BANNER-->---
@@ -12,7 +12,7 @@
 <!--END STABILITY BANNER-->
 
 This module is part of the [AWS Cloud Development Kit](https://github.com/aws/aws-cdk) project.
-"""
+'''
 import abc
 import builtins
 import datetime
@@ -34,11 +34,11 @@ class CfnPipeline(
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-cdk/aws-datapipeline.CfnPipeline",
 ):
-    """A CloudFormation ``AWS::DataPipeline::Pipeline``.
+    '''A CloudFormation ``AWS::DataPipeline::Pipeline``.
 
-    :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
     :cloudformationResource: AWS::DataPipeline::Pipeline
-    """
+    :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
+    '''
 
     def __init__(
         self,
@@ -53,7 +53,7 @@ class CfnPipeline(
         pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]] = None,
         pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]] = None,
     ) -> None:
-        """Create a new ``AWS::DataPipeline::Pipeline``.
+        '''Create a new ``AWS::DataPipeline::Pipeline``.
 
         :param scope: - scope in which this resource is defined.
         :param id: - scoped id of the resource.
@@ -64,7 +64,7 @@ class CfnPipeline(
         :param parameter_values: ``AWS::DataPipeline::Pipeline.ParameterValues``.
         :param pipeline_objects: ``AWS::DataPipeline::Pipeline.PipelineObjects``.
         :param pipeline_tags: ``AWS::DataPipeline::Pipeline.PipelineTags``.
-        """
+        '''
         props = CfnPipelineProps(
             name=name,
             parameter_objects=parameter_objects,
@@ -79,145 +79,145 @@ class CfnPipeline(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        """(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''(experimental) Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
 
         :stability: experimental
-        """
-        return jsii.invoke(self, "inspect", [inspector])
+        '''
+        return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
     @jsii.member(jsii_name="renderProperties")
     def _render_properties(
         self,
         props: typing.Mapping[builtins.str, typing.Any],
     ) -> typing.Mapping[builtins.str, typing.Any]:
-        """
+        '''
         :param props: -
-        """
-        return jsii.invoke(self, "renderProperties", [props])
+        '''
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.invoke(self, "renderProperties", [props]))
 
-    @jsii.python.classproperty # type: ignore
+    @jsii.python.classproperty # type: ignore[misc]
     @jsii.member(jsii_name="CFN_RESOURCE_TYPE_NAME")
     def CFN_RESOURCE_TYPE_NAME(cls) -> builtins.str:
-        """The CloudFormation resource type name for this resource class."""
-        return jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME")
+        '''The CloudFormation resource type name for this resource class.'''
+        return typing.cast(builtins.str, jsii.sget(cls, "CFN_RESOURCE_TYPE_NAME"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="cfnProperties")
     def _cfn_properties(self) -> typing.Mapping[builtins.str, typing.Any]:
-        return jsii.get(self, "cfnProperties")
+        return typing.cast(typing.Mapping[builtins.str, typing.Any], jsii.get(self, "cfnProperties"))
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="name")
     def name(self) -> builtins.str:
-        """``AWS::DataPipeline::Pipeline.Name``.
+        '''``AWS::DataPipeline::Pipeline.Name``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
-        """
-        return jsii.get(self, "name")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
+        '''
+        return typing.cast(builtins.str, jsii.get(self, "name"))
 
-    @name.setter # type: ignore
+    @name.setter
     def name(self, value: builtins.str) -> None:
         jsii.set(self, "name", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="parameterObjects")
     def parameter_objects(
         self,
     ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]]:
-        """``AWS::DataPipeline::Pipeline.ParameterObjects``.
+        '''``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
-        """
-        return jsii.get(self, "parameterObjects")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
+        '''
+        return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]], jsii.get(self, "parameterObjects"))
 
-    @parameter_objects.setter # type: ignore
+    @parameter_objects.setter
     def parameter_objects(
         self,
         value: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union["CfnPipeline.ParameterObjectProperty", aws_cdk.core.IResolvable]]],
     ) -> None:
         jsii.set(self, "parameterObjects", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="activate")
     def activate(
         self,
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
-        """``AWS::DataPipeline::Pipeline.Activate``.
+        '''``AWS::DataPipeline::Pipeline.Activate``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
-        """
-        return jsii.get(self, "activate")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
+        '''
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], jsii.get(self, "activate"))
 
-    @activate.setter # type: ignore
+    @activate.setter
     def activate(
         self,
         value: typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]],
     ) -> None:
         jsii.set(self, "activate", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="description")
     def description(self) -> typing.Optional[builtins.str]:
-        """``AWS::DataPipeline::Pipeline.Description``.
+        '''``AWS::DataPipeline::Pipeline.Description``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
-        """
-        return jsii.get(self, "description")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
+        '''
+        return typing.cast(typing.Optional[builtins.str], jsii.get(self, "description"))
 
-    @description.setter # type: ignore
+    @description.setter
     def description(self, value: typing.Optional[builtins.str]) -> None:
         jsii.set(self, "description", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="parameterValues")
     def parameter_values(
         self,
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]]:
-        """``AWS::DataPipeline::Pipeline.ParameterValues``.
+        '''``AWS::DataPipeline::Pipeline.ParameterValues``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
-        """
-        return jsii.get(self, "parameterValues")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
+        '''
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]], jsii.get(self, "parameterValues"))
 
-    @parameter_values.setter # type: ignore
+    @parameter_values.setter
     def parameter_values(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterValueProperty"]]]],
     ) -> None:
         jsii.set(self, "parameterValues", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="pipelineObjects")
     def pipeline_objects(
         self,
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]]:
-        """``AWS::DataPipeline::Pipeline.PipelineObjects``.
+        '''``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
-        """
-        return jsii.get(self, "pipelineObjects")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
+        '''
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]], jsii.get(self, "pipelineObjects"))
 
-    @pipeline_objects.setter # type: ignore
+    @pipeline_objects.setter
     def pipeline_objects(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineObjectProperty"]]]],
     ) -> None:
         jsii.set(self, "pipelineObjects", value)
 
-    @builtins.property # type: ignore
+    @builtins.property # type: ignore[misc]
     @jsii.member(jsii_name="pipelineTags")
     def pipeline_tags(
         self,
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]]:
-        """``AWS::DataPipeline::Pipeline.PipelineTags``.
+        '''``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
-        """
-        return jsii.get(self, "pipelineTags")
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
+        '''
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]], jsii.get(self, "pipelineTags"))
 
-    @pipeline_tags.setter # type: ignore
+    @pipeline_tags.setter
     def pipeline_tags(
         self,
         value: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.PipelineTagProperty"]]]],
@@ -241,13 +241,13 @@ class CfnPipeline(
             ref_value: typing.Optional[builtins.str] = None,
             string_value: typing.Optional[builtins.str] = None,
         ) -> None:
-            """
+            '''
             :param key: ``CfnPipeline.FieldProperty.Key``.
             :param ref_value: ``CfnPipeline.FieldProperty.RefValue``.
             :param string_value: ``CfnPipeline.FieldProperty.StringValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html
+            '''
             self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
             }
@@ -258,31 +258,31 @@ class CfnPipeline(
 
         @builtins.property
         def key(self) -> builtins.str:
-            """``CfnPipeline.FieldProperty.Key``.
+            '''``CfnPipeline.FieldProperty.Key``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-key
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-key
+            '''
             result = self._values.get("key")
             assert result is not None, "Required property 'key' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         @builtins.property
         def ref_value(self) -> typing.Optional[builtins.str]:
-            """``CfnPipeline.FieldProperty.RefValue``.
+            '''``CfnPipeline.FieldProperty.RefValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-refvalue
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-refvalue
+            '''
             result = self._values.get("ref_value")
-            return result
+            return typing.cast(typing.Optional[builtins.str], result)
 
         @builtins.property
         def string_value(self) -> typing.Optional[builtins.str]:
-            """``CfnPipeline.FieldProperty.StringValue``.
+            '''``CfnPipeline.FieldProperty.StringValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-stringvalue
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects-fields.html#cfn-datapipeline-pipeline-pipelineobjects-fields-stringvalue
+            '''
             result = self._values.get("string_value")
-            return result
+            return typing.cast(typing.Optional[builtins.str], result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -302,12 +302,12 @@ class CfnPipeline(
     )
     class ParameterAttributeProperty:
         def __init__(self, *, key: builtins.str, string_value: builtins.str) -> None:
-            """
+            '''
             :param key: ``CfnPipeline.ParameterAttributeProperty.Key``.
             :param string_value: ``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html
+            '''
             self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "string_value": string_value,
@@ -315,23 +315,23 @@ class CfnPipeline(
 
         @builtins.property
         def key(self) -> builtins.str:
-            """``CfnPipeline.ParameterAttributeProperty.Key``.
+            '''``CfnPipeline.ParameterAttributeProperty.Key``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-key
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-key
+            '''
             result = self._values.get("key")
             assert result is not None, "Required property 'key' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         @builtins.property
         def string_value(self) -> builtins.str:
-            """``CfnPipeline.ParameterAttributeProperty.StringValue``.
+            '''``CfnPipeline.ParameterAttributeProperty.StringValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-stringvalue
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects-attributes.html#cfn-datapipeline-pipeline-parameterobjects-attribtues-stringvalue
+            '''
             result = self._values.get("string_value")
             assert result is not None, "Required property 'string_value' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -356,12 +356,12 @@ class CfnPipeline(
             attributes: typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]],
             id: builtins.str,
         ) -> None:
-            """
+            '''
             :param attributes: ``CfnPipeline.ParameterObjectProperty.Attributes``.
             :param id: ``CfnPipeline.ParameterObjectProperty.Id``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html
+            '''
             self._values: typing.Dict[str, typing.Any] = {
                 "attributes": attributes,
                 "id": id,
@@ -371,23 +371,23 @@ class CfnPipeline(
         def attributes(
             self,
         ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]]:
-            """``CfnPipeline.ParameterObjectProperty.Attributes``.
+            '''``CfnPipeline.ParameterObjectProperty.Attributes``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-attributes
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-attributes
+            '''
             result = self._values.get("attributes")
             assert result is not None, "Required property 'attributes' is missing"
-            return result
+            return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.ParameterAttributeProperty"]]], result)
 
         @builtins.property
         def id(self) -> builtins.str:
-            """``CfnPipeline.ParameterObjectProperty.Id``.
+            '''``CfnPipeline.ParameterObjectProperty.Id``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-id
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parameterobjects.html#cfn-datapipeline-pipeline-parameterobjects-id
+            '''
             result = self._values.get("id")
             assert result is not None, "Required property 'id' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -407,12 +407,12 @@ class CfnPipeline(
     )
     class ParameterValueProperty:
         def __init__(self, *, id: builtins.str, string_value: builtins.str) -> None:
-            """
+            '''
             :param id: ``CfnPipeline.ParameterValueProperty.Id``.
             :param string_value: ``CfnPipeline.ParameterValueProperty.StringValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html
+            '''
             self._values: typing.Dict[str, typing.Any] = {
                 "id": id,
                 "string_value": string_value,
@@ -420,23 +420,23 @@ class CfnPipeline(
 
         @builtins.property
         def id(self) -> builtins.str:
-            """``CfnPipeline.ParameterValueProperty.Id``.
+            '''``CfnPipeline.ParameterValueProperty.Id``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-id
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-id
+            '''
             result = self._values.get("id")
             assert result is not None, "Required property 'id' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         @builtins.property
         def string_value(self) -> builtins.str:
-            """``CfnPipeline.ParameterValueProperty.StringValue``.
+            '''``CfnPipeline.ParameterValueProperty.StringValue``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-stringvalue
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-parametervalues.html#cfn-datapipeline-pipeline-parametervalues-stringvalue
+            '''
             result = self._values.get("string_value")
             assert result is not None, "Required property 'string_value' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -462,13 +462,13 @@ class CfnPipeline(
             id: builtins.str,
             name: builtins.str,
         ) -> None:
-            """
+            '''
             :param fields: ``CfnPipeline.PipelineObjectProperty.Fields``.
             :param id: ``CfnPipeline.PipelineObjectProperty.Id``.
             :param name: ``CfnPipeline.PipelineObjectProperty.Name``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html
+            '''
             self._values: typing.Dict[str, typing.Any] = {
                 "fields": fields,
                 "id": id,
@@ -479,33 +479,33 @@ class CfnPipeline(
         def fields(
             self,
         ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]]:
-            """``CfnPipeline.PipelineObjectProperty.Fields``.
+            '''``CfnPipeline.PipelineObjectProperty.Fields``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-fields
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-fields
+            '''
             result = self._values.get("fields")
             assert result is not None, "Required property 'fields' is missing"
-            return result
+            return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, "CfnPipeline.FieldProperty"]]], result)
 
         @builtins.property
         def id(self) -> builtins.str:
-            """``CfnPipeline.PipelineObjectProperty.Id``.
+            '''``CfnPipeline.PipelineObjectProperty.Id``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-id
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-id
+            '''
             result = self._values.get("id")
             assert result is not None, "Required property 'id' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         @builtins.property
         def name(self) -> builtins.str:
-            """``CfnPipeline.PipelineObjectProperty.Name``.
+            '''``CfnPipeline.PipelineObjectProperty.Name``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-name
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelineobjects.html#cfn-datapipeline-pipeline-pipelineobjects-name
+            '''
             result = self._values.get("name")
             assert result is not None, "Required property 'name' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -525,12 +525,12 @@ class CfnPipeline(
     )
     class PipelineTagProperty:
         def __init__(self, *, key: builtins.str, value: builtins.str) -> None:
-            """
+            '''
             :param key: ``CfnPipeline.PipelineTagProperty.Key``.
             :param value: ``CfnPipeline.PipelineTagProperty.Value``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html
+            '''
             self._values: typing.Dict[str, typing.Any] = {
                 "key": key,
                 "value": value,
@@ -538,23 +538,23 @@ class CfnPipeline(
 
         @builtins.property
         def key(self) -> builtins.str:
-            """``CfnPipeline.PipelineTagProperty.Key``.
+            '''``CfnPipeline.PipelineTagProperty.Key``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-key
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-key
+            '''
             result = self._values.get("key")
             assert result is not None, "Required property 'key' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         @builtins.property
         def value(self) -> builtins.str:
-            """``CfnPipeline.PipelineTagProperty.Value``.
+            '''``CfnPipeline.PipelineTagProperty.Value``.
 
-            :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-value
-            """
+            :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-datapipeline-pipeline-pipelinetags.html#cfn-datapipeline-pipeline-pipelinetags-value
+            '''
             result = self._values.get("value")
             assert result is not None, "Required property 'value' is missing"
-            return result
+            return typing.cast(builtins.str, result)
 
         def __eq__(self, rhs: typing.Any) -> builtins.bool:
             return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -593,7 +593,7 @@ class CfnPipelineProps:
         pipeline_objects: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]] = None,
         pipeline_tags: typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]] = None,
     ) -> None:
-        """Properties for defining a ``AWS::DataPipeline::Pipeline``.
+        '''Properties for defining a ``AWS::DataPipeline::Pipeline``.
 
         :param name: ``AWS::DataPipeline::Pipeline.Name``.
         :param parameter_objects: ``AWS::DataPipeline::Pipeline.ParameterObjects``.
@@ -603,8 +603,8 @@ class CfnPipelineProps:
         :param pipeline_objects: ``AWS::DataPipeline::Pipeline.PipelineObjects``.
         :param pipeline_tags: ``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html
+        '''
         self._values: typing.Dict[str, typing.Any] = {
             "name": name,
             "parameter_objects": parameter_objects,
@@ -622,78 +622,78 @@ class CfnPipelineProps:
 
     @builtins.property
     def name(self) -> builtins.str:
-        """``AWS::DataPipeline::Pipeline.Name``.
+        '''``AWS::DataPipeline::Pipeline.Name``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-name
+        '''
         result = self._values.get("name")
         assert result is not None, "Required property 'name' is missing"
-        return result
+        return typing.cast(builtins.str, result)
 
     @builtins.property
     def parameter_objects(
         self,
     ) -> typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, aws_cdk.core.IResolvable]]]:
-        """``AWS::DataPipeline::Pipeline.ParameterObjects``.
+        '''``AWS::DataPipeline::Pipeline.ParameterObjects``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parameterobjects
+        '''
         result = self._values.get("parameter_objects")
         assert result is not None, "Required property 'parameter_objects' is missing"
-        return result
+        return typing.cast(typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[CfnPipeline.ParameterObjectProperty, aws_cdk.core.IResolvable]]], result)
 
     @builtins.property
     def activate(
         self,
     ) -> typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]]:
-        """``AWS::DataPipeline::Pipeline.Activate``.
+        '''``AWS::DataPipeline::Pipeline.Activate``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-activate
+        '''
         result = self._values.get("activate")
-        return result
+        return typing.cast(typing.Optional[typing.Union[builtins.bool, aws_cdk.core.IResolvable]], result)
 
     @builtins.property
     def description(self) -> typing.Optional[builtins.str]:
-        """``AWS::DataPipeline::Pipeline.Description``.
+        '''``AWS::DataPipeline::Pipeline.Description``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-description
+        '''
         result = self._values.get("description")
-        return result
+        return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
     def parameter_values(
         self,
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.ParameterValueProperty]]]]:
-        """``AWS::DataPipeline::Pipeline.ParameterValues``.
+        '''``AWS::DataPipeline::Pipeline.ParameterValues``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-parametervalues
+        '''
         result = self._values.get("parameter_values")
-        return result
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.ParameterValueProperty]]]], result)
 
     @builtins.property
     def pipeline_objects(
         self,
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]]:
-        """``AWS::DataPipeline::Pipeline.PipelineObjects``.
+        '''``AWS::DataPipeline::Pipeline.PipelineObjects``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelineobjects
+        '''
         result = self._values.get("pipeline_objects")
-        return result
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineObjectProperty]]]], result)
 
     @builtins.property
     def pipeline_tags(
         self,
     ) -> typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]]:
-        """``AWS::DataPipeline::Pipeline.PipelineTags``.
+        '''``AWS::DataPipeline::Pipeline.PipelineTags``.
 
-        :see: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
-        """
+        :link: http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-datapipeline-pipeline.html#cfn-datapipeline-pipeline-pipelinetags
+        '''
         result = self._values.get("pipeline_tags")
-        return result
+        return typing.cast(typing.Optional[typing.Union[aws_cdk.core.IResolvable, typing.List[typing.Union[aws_cdk.core.IResolvable, CfnPipeline.PipelineTagProperty]]]], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
